@@ -16,7 +16,7 @@
  * @subpackage util
  * @author     Fabien Potencier <fabien.potencier@symfony-project.com>
  * @author     Sean Kerr <sean@code-box.org>
- * @version    SVN: $Id: sfToolkit.class.php 10833 2008-08-13 11:33:13Z fabien $
+ * @version    SVN: $Id: sfToolkit.class.php 13893 2008-12-09 22:30:43Z FabianLange $
  */
 class sfToolkit
 {
@@ -181,33 +181,21 @@ class sfToolkit
       return $source;
     }
 
+    $ignore = array(T_COMMENT => true, T_DOC_COMMENT => true);
     $output = '';
 
-    $tokens = token_get_all($source);
-    foreach ($tokens as $token)
-    {
-      if (is_string($token))
-      {
+    foreach (token_get_all($source) as $token) {
+      // array
+      if (isset($token[1])) {
+        // no action on comments
+        if (!isset($ignore[$token[0]])) {
+          // anything else -> output "as is"
+          $output .= $token[1];
+        }
+      } else {
         // simple 1-character token
         $output .= $token;
       }
-      else
-      {
-        // token array
-        list($id, $text) = $token;
-
-        switch ($id)
-        {
-          case T_COMMENT:
-          case T_DOC_COMMENT:
-            // no action on comments
-            break;
-          default:
-            // anything else -> output "as is"
-            $output .= $text;
-            break;
-        }
-      }
     }
 
     return $output;
